pub enum PounceSolverSelection {
Auto,
Nlp,
LpIpm,
QpIpm,
QpActiveSet,
Socp,
}Expand description
POUNCE solver route selected after classifying the oximo model.
Variants
Auto
Use a specialized convex engine when convexity is certified, otherwise use the general NLP engine.
Nlp
Always use the general NLP engine.
LpIpm
Force the convex LP interior-point route (LP models only).
QpIpm
Force the convex QP interior-point route (LP or convex QP).
QpActiveSet
Force POUNCE’s direct parametric active-set QP engine.
Socp
Force the conic interior-point route (convex LP/QP/SOCP).